@@ -4,6 +4,7 @@ from djangoldp.models import Model
 from django.db.models.signals import post_save
 from django.dispatch import receiver
 from django.template import loader
+from datetime import datetime
 
 class Typemember (Model):
     name = models.CharField(max_length=50, verbose_name="Type of member")
@@ -29,7 +30,7 @@ class Member (Model):
     birthcountry = models.CharField(max_length=50, blank=True, null=True, verbose_name="Birth country")
     corponame = models.CharField(max_length=50, blank=True, null=True,verbose_name="Corporate Name")
     mandat = models.CharField(max_length=50, blank=True, null=True,verbose_name="Social mandate")
-    siret = models.IntegerField(blank=True, null=True, verbose_name="Siret")
+    siret = models.CharField(max_length=15, blank=True, null=True, verbose_name="Siret")
     numberaddress = models.CharField(max_length=10, verbose_name="Street number")
     streetaddress = models.CharField(max_length=50, verbose_name="Street name")
     zipcode = models.CharField(max_length=10, verbose_name="Zip code")
@@ -44,6 +45,7 @@ class Member (Model):
     beneficiciaireconfirmation  = models.BooleanField(verbose_name="Bénéficiaire subscription")
     partquantity = models.IntegerField(verbose_name="Part Quantity")
     iddocument = models.URLField(blank=True, null=True, verbose_name="ID")
+    subscriptiondate = models.DateTimeField(default=datetime.now, blank=True, null=True, verbose_name="Subscription date")
 
     class Meta : 
         anonymous_perms = ['view', 'add', 'change']
